**********************************************************************
* name of this file: 
* Exercise2_4.do
* Exercise 2: Determine household size 
* Exercise 3: Youngest child in household
* Exercise 4: Number of unemployed household members
*
* DwB Training Course on EU-SILC Longitudinal Data
* Heike Wirth, GESIS
**********************************************************************

clear
capture log close
set more off

* change the path to where your original data is stored
cd "YOUR PATH"

* choose name and directory for your loglog-file
log using "YOUR LOG FILE", append

**********************************************************************
* (d) Create new household level summary variables 
*     from person level information, e.g. 
* 
*    - Age of the youngest child in household
*    - Number of current household members
*    - Number of unemployed persons in household
* 
*  
* further examples
* 
* number of self-employed persons
* number of employed persons
* number of retired persons
* by using PL040, PL030, PL031 
* 
**********************************************************************

use "person_reg_data.dta",clear

**********************************************************************
* Exercise 2: Determine household size 
**********************************************************************

**********************************************************************	 
* required variables to identify households
* YEAR, COUNTRY, HH_ID, PERS_ID
**********************************************************************

sort YEAR COUNTRY HH_ID PERS_ID

* (1) create an auxiliary variable "MEMBER" with value 1 for each person.

gen MEMBER = 1
tab MEMBER
list YEAR COUNTRY HH_ID PERS_ID in 165/188, clean

* (2) create a new household variable 'HHSIZE' 

egen HHSIZE = sum(MEMBER), by (YEAR COUNTRY HH_ID)
list YEAR COUNTRY HH_ID PERS_ID MEMBER HHSIZE in 165/188, clean

tab  COUNTRY HHSIZE, row nofreq


* => gives you the percentage/number of persons living 
* in a 1-;2-;3- ... person household
* 

**********************************************************************
* When creating household information at the personal level
* information could refer to households or persons
* Reference to household can be achieved by
* creating a household reference person 
* e.g. the first person in every household
**********************************************************************

bysort YEAR COUNTRY HH_ID : gen HH_MEM=_n

tab HHSIZE if HH_MEM==1

* => gives you the percentage/number of 1-;2-;3- ... person household


* Exercise 3: Youngest child in household

**********************************************************************
* Age of youngest child in household ?
* (a) For all hh with numchild > 0 
* (b) Categorize age of youngest child into 
*     age group 0-2, 3-5, 6-8, 9-12
**********************************************************************

**********************************************************************
* Step 1: create a  variable CHILD which is 
*         0 if Age >= 18 
*         1 if age < 18
**********************************************************************

egen HH_YCHILD=min(RX010), by(YEAR COUNTRY HH_ID)
recode HH_YCHILD 18/80=.
label var HH_YCHILD "age of the youngest child in the HH"

tab1 HH_YCHILD if HH_MEM==1, m
tab  HH_YCHILD  if HH_MEM==1


**********************************************************************
* Exercise 4: Number of unemployed household members
**********************************************************************

use "person_reg_data.dta",clear

* Use PL030 & PL031 to create a new variable UNEMP
* Why use two variables for generating the variable unemployed ???

tab PL030 PL031, m nolab

gen UNEMP=1 if PL030==3 | PL031==5 
tab PL030 UNEMP,m
tab PL031 UNEMP,m

* Use PL040 to create a new variable SELF_EMP
gen SELF_EMP=1 if PL040==1 | PL040==2 | PL040==4
tab PL030 SELF_EMP, m
tab PL031 SELF_EMP, m


* Use PL040 to create a new variable EMP
gen EMP=1 if PL040==3
tab PL030 EMP, m
tab PL031 EMP, m


* Use PL030 & PL30 to create a new variable RETIRE

gen RETIRE=1 if PL030==5 | PL031==7
tab PL030 RETIRE,m
tab PL031 RETIRE,m


sort COUNTRY  HH_ID YEAR  PERS_ID
list YEAR COUNTRY HH_ID PERS_ID SELF_EMP EMP UNEMP RETIRE in 1/15, c clean nolab

egen SELF_EMPC =count(SELF_EMP) , by(YEAR COUNTRY HH_ID)
egen      EMPC =count(EMP)      , by(YEAR COUNTRY HH_ID)
egen    UNEMPC =count(UNEMP)    , by(YEAR COUNTRY HH_ID)
egen   RETIREC =count(RETIRE)   , by(YEAR COUNTRY HH_ID)

list YEAR HH_ID PERS_ID SELF_EMP EMP UNEMP RETIRE SELF_EMPC EMPC UNEMPC RETIREC in 1/15, c clean nolab

* Change from personal level to the household level

* Alternative 1
* 
* keep if HH_MEM==1
* keep YEAR COUNTRY HH_ID SELF_EMPC EMPC UNEMPC RETIREC
* tab YEAR SELF_EMPC
* tab YEAR EMPC
* tab YEAR UNEMPC
* tab YEAR RETIREC

* Alternative 2
*
* use  the collapse command to replace dataset by one containing 
* number of SELF_EMP EMP UNEMP RETIRE persons in HH

collapse (count)SELF_EMP EMP UNEMP RETIRE, by(YEAR COUNTRY HH_ID)
list YEAR COUNTRY HH_ID SELF_EMP EMP UNEMP RETIRE  in 1/15, c clean nolab

save "HH_var.dta", replace

* Merge with household data

use "hh_reg_data.dta", clear

merge 1:1 YEAR COUNTRY HH_ID using HH_var.dta
tab _merge
