**********************************************************************
* name of this file: 
* Exercise9.do
* 
* Determine the change in the marital status and status in employment status
* across years  
*
* DwB Training Course on EU-SILC Longitudinal Data
* Paris, 19-21 February 2014
* Hands-on 
* Heike Wirth, GESIS
*
* see: Bruederl/Ludwig: Useful Stata Commands for
* Longitudinal Data Analysis
* University of Munich, May 2012
* http://www.ls3.soziologie.uni-muenchen.de/
* downloads/lehre/lehre_alt/statacommands.pdf
**********************************************************************


clear
capture log close
set more off

* change the path to where your original data is stored
cd "D:\Eigene Dateien\Dokumente\PARIS_2014\EXERCISE\DATA"

* choose name and directory for your loglog-file
log using "D:\Eigene Dateien\Dokumente\PARIS_2014\EXERCISE\hw_log", replace


**********************************************************************
*
* Using information from the year before
* X[1]    // X value of the first household/person year
* X[_N]   // X value of the last household/person year
* X[_n-1] // X value of the household/person year before
*  
**********************************************************************

use "person_reg_data.dta",clear
sort COUNTRY HH_ID PERS_ID YEAR

* Exercise 9: changes in the marital status 
* PB190 'marital status' 
* 

bysort HH_ID COUNTRY PERS_ID (YEAR) : gen FIRST_PB190=PB190[1]    //value of the first person year
bysort HH_ID COUNTRY PERS_ID (YEAR) : gen LAST_PB190 =PB190[_N]   //value of the last person year
bysort HH_ID COUNTRY PERS_ID (YEAR) : gen YB_PB190   =PB190[_n-1] //value of the previous person year

list COUNTRY HH_ID YEAR PB190 FIRST_PB190 LAST_PB190 YB_PB190 in 1/20, clean nolab

* "change" between first person year and last person year
*  main diagonal = 'stayers (no change between first & last hhyear)'

tab FIRST_PB190 LAST_PB190, row nofreq

* "change" between 'person year of interest' and previous person year

bysort YEAR: tab PB190 YB_PB190
bysort YEAR: tab PB190 YB_PB190, row nofreq


* Changes in employment status (PL040) over time

tab PL040

bysort HH_ID COUNTRY PERS_ID (YEAR) : gen FIRST_PL040=PL040[1]    //value of the first person year
bysort HH_ID COUNTRY PERS_ID (YEAR) : gen LAST_PL040 =PL040[_N]   //value of the last person year
bysort HH_ID COUNTRY PERS_ID (YEAR) : gen YB_PL040   =PL040[_n-1] //value of the previous person year 

list COUNTRY HH_ID YEAR PL040 FIRST_PL040 LAST_PL040 YB_PL040 in 1/20, clean nolab

* "change" between first person year and last person year
*  main diagonal = 'stayers (no change between first & last person year)'

tab PL040

tab FIRST_PL040 LAST_PL040, row nofreq

* change in the employment status over time by highest isced level attained
* reference population persons >= 18

bysort YEAR: tab PL040 YB_PL040
bysort YEAR: tab PL040 YB_PL040, row nofreq

bysort PE040:tab FIRST_PL040 LAST_PL040 if RX010 >=18 , row nofreq

