**********************************************************************
* name of this file: 
* merge.do
*
* DwB Training Course on EU-SILC Longitudinal Data
* Paris, 19-21 February 2014
* Hands-on 
* Heike Wirth, GESIS
**********************************************************************

clear
capture log close
set more off

* change the path to where your original data is stored
cd "YOUR PATH"

* choose name and directory for your loglog-file
log using "YOUR LOG FILE"

**********************************************************************
*
* Merging SILC data
*
* This syntax shows you how you can merge SILC datasets
* a) Person register and data file (R & P file)
* b) Household register and data file (D & H file)
* c) Merge household information to person data
* d) Generate household data from person information
**********************************************************************

**********************************************************************
*
* We assume that data are prepared by "start.do" !!!!!!!!!!!
*
**********************************************************************

**********************************************************************
*
* a) Merge person-level register data and person data
*  
**********************************************************************

use "pers_reg_l2011.dta", replace

tab1 YEAR COUNTRY

merge 1:1 YEAR COUNTRY HH_ID PERS_ID using "pers_data_l2011.dta"
tab _merge

numlabel, add
* explore data
tab RB110 _merge,m 
tab RB110 _merge if RX010 >15,m 

* Register file contains more cases
* a) Household member below 16 years
* b) Persons not belonging to a household any longer

* for the longitudinal analysis we remove persns not currently 
* in a SILC household RB110 > 4

drop if RB110 >= 5 & RB110 <=7

tab RB110 _merge,m 
drop _merge

save "person_reg_data.dta", replace


**********************************************************************
*
* b) Merge household-level register data and household data
*  
**********************************************************************

*** Note: there are way more cases in household register than in household data***

use "hh_reg_l2011.dta", clear

merge 1:1 YEAR COUNTRY HH_ID using hh_data_l2011.dta
tab _merge

*** we only keep households with information in the data file
keep if _merge==3
drop _merge
save "hh_reg_data.dta", replace

**********************************************************************
*
* c) Merge household information to person data
*  
**********************************************************************

***Variables of interest household size (HX040), equivalized household size (HX050)

use "hh_reg_data.dta", clear

keep YEAR COUNTRY HH_ID HX040 HX050

merge 1:m YEAR COUNTRY HH_ID using person_reg_data.dta
tab _merge

format PERS_ID %12.0g
list YEAR COUNTRY HH_ID PERS_ID if _merge==2

keep if _merge==3
drop _merge

* Here you can begin your own analysis, what jhousehold characteristic 
* would you lioke to analyse together with person data on the person level?
* One example could be DB100 "Degree of Urbanisation" found in the 
* household register data.
*
* ...


**********************************************************************
*
* d) Generate household data from person information
*  
**********************************************************************

* Example:
* Counting the number of persons under 18 years in household
* Note: egen(count) counts nonmissing values only*** 
* Two steps: first generate an individual identifier then count in HH***

use "person_reg_data.dta",clear

gen CHILD=.
recode CHILD .=1 if RX010<18 
tab CHILD

egen CHILDC =count(CHILD) , by(YEAR COUNTRY HH_ID)
label var CHILDC "Number of persons under 18 in HH"
tab CHILDC

* In order to be able to display frequencies for households we need a 
* variable identifying the first person in the HH

bysort YEAR COUNTRY HH_ID : gen HH_MEM=_n

bysort YEAR : tab CHILDC if HH_MEM==1 
bysort YEAR : tab COUNTRY CHILDC if HH_MEM==1, row

keep if HH_MEM==1
keep YEAR COUNTRY HH_ID CHILDC
tab YEAR CHILDC 

save "HH_var.dta", replace

* Merge with household data

use "hh_reg_data.dta", clear

merge 1:1 YEAR COUNTRY HH_ID using HH_var.dta
tab _merge

tab CHILDC HS100, row

