**********************************************************************
* name of this file: 
* reshape_wide.do
*
* DwB Training Course on EU-SILC Longitudinal Data
* Paris, 19-21 February 2014
* Hands-on 
* Heike Wirth, GESIS
**********************************************************************

clear
capture log close
set more off

* change the path to where your original data is stored
cd "YOUR PATH"

* choose name and directory for your loglog-file
log using "YOUR LOG FILE", append

**********************************************************************
*
* Transforming SILC data from long to wide format
*
**********************************************************************

**********************************************************************
*
* We assume that data are prepared by "start.do" and "merge.do" !!!!!!
*
**********************************************************************

cd "D:\Eigene Dateien\Daten\SILC\Training\STATA"

use "hh_reg_data.dta", replace
tab1 COUNTRY YEAR

* As poverty threshhold we use 60% of the median of equivalized income.
* The information on poverty lines are taken from Eurostat
* http://appsso.eurostat.ec.europa.eu/nui/show.do?dataset=ilc_li01&lang=en

merge m:1 YEAR COUNTRY using povertylines.dta
tab COUNTRY _merge 
keep if _merge==3
drop _merge

gen POOR=.
replace POOR=0 if HX090 >= POVLINE
replace POOR=1 if HX090 < POVLINE 
label variable POOR "Poverty Indicator (HX080)"
label define ny 0 "no" 1 "yes"
label values POOR ny
bysort COUNTRY: tab YEAR POOR, row

* Create unique household ID

duplicates report HH_ID YEAR

egen COUNTRY_NO=group(COUNTRY)
gen double HH_IDENTIFIER  = (COUNTRY_NO*1000000000 + HH_ID)
format HH_IDENTIFIER %16.0g
tabstat HH_IDENTIFIER, stats(min max count) format(%16.0g)
duplicates report HH_IDENTIFIER YEAR
isid HH_IDENTIFIER YEAR

* To go from long to wide format you first should reduce your data matrix 
* to the variables you would like to work with in the wide file;
* here we are only interested in the poverty indicator and the indicator
* Making ends meets (HS120). In addition we keep the key variables.

keep COUNTRY YEAR HH_IDENTIFIER HS120 POOR
reshape wide HS120 POOR, i(HH_IDENTIFIER) j(YEAR)

tab2 HS1202009 HS1202008, col gamma
tab2 HS1202010 HS1202009, col gamma
tab2 HS1202011 HS1202010, col gamma

tab2 POOR2009 POOR2008, col V
tab2 POOR2010 POOR2009, col V
tab2 POOR2011 POOR2010, col V
