**********************************************************************
* name of this file: 
* start.do
*
* DwB Training Course on EU-SILC Longitudinal Data
* Paris, 19-21 February 2014
* Hands-on 
* Heike Wirth, GESIS
**********************************************************************

clear
capture log close
set more off

* change the path to where your original data is stored
cd "YOUR PATH"

* choose name and directory for your loglog-file
log using "YOUR LOG FILE"

**********************************************************************
* Step 1
* open the original data and save them using a new name
*
* The original file names for SILC 2011 longitudinal data are:
*
* UDB_l11D_ver 2011-1 from 01-08-2013.dta => hh_reg_l2011.dta
* UDB_l11H_ver 2011-1 from 01-08-2013.dta => hh_data_l2011.dta
* UDB_l11R_ver 2011-1 from 01-08-2013.dta => pers_reg_l2011.dta
* UDB_l11P_ver 2011-1 from 01-08-2013.dta => pers_data_l2011.dta
*
* The training data have different names, these are:
*
* udb_l11d_silc_course.dta => hh_reg_l2011.dta
* udb_l11h_silc_course.dta => hh_data_l2011.dta
* udb_l11r_silc_course.dta => pers_reg_l2011.dta
* udb_l11p_silc_course.dta => pers_data_l2011.dta
*
* DISCLAIMER: We assume that you have prepared the stata files using the
*             syntax provided by GESIS; you will find the files at:
*
* http://www.gesis.org/en/services/data-analysis/official-microdata/european-microdata/eu-silc/eu-silc-tools/
*
**********************************************************************


**********************************************************************
* KEY VARIABLES
* In order to link the four files D; H; R and P 
* all observations must have a unique link to the three other files
* This link is achieved by the following 4 key variables
*
* (1)Year of Survey: DB010; HB010; RB010; PB010
* (2)Country:        DB020; HB020; RB020; PB020 (alphanumerical codes)
*    alternative     DB020_num; HB020_num; RB020_num; PB020_num
* (3)Household ID:   DB030; HB030; RX030; PX030
* (4)Personal ID:    RB030; PB030

* KEY VARIABLES should be named identical in all 4 Files
* Files should be sorted according the KEY VARIABLES
**********************************************************************

**********************************************************************
* household register
**********************************************************************
* 1. open the file
use  "udb_l11d_silc_course.dta", clear

* 2. rename the KEY VARIABLES
rename DB010     YEAR
rename DB020     COUNTRY
rename DB030     HH_ID

* check
tab1 YEAR COUNTRY
tabstat HH_ID, stats(min max n) by (COUNTRY) format(%10.0g)

* 3. sort the KEY variables
sort YEAR COUNTRY HH_ID

* 4. save the file under a new name, change path to your own path 
save "hh_reg_l2011.dta", replace
**********************************************************************

**********************************************************************
* household data
**********************************************************************
* 1. open the file
use  "udb_l11h_silc_course.dta", clear

* rename the key variables
rename HB010     YEAR
rename HB020     COUNTRY
rename HB030     HH_ID

* check
tab1 YEAR COUNTRY
tabstat HH_ID, stats(min max n) by (COUNTRY) format(%10.0g)

* sort by key variables
sort YEAR COUNTRY HH_ID

* save the file under a new name, change path to your own path 
save "hh_data_l2011.dta", replace
**********************************************************************

**********************************************************************
* personal register
**********************************************************************
* 1. open the file
use  "udb_l11r_silc_course.dta", clear

* 2. rename the KEY VARIABLES
rename RB010     YEAR
rename RB020     COUNTRY
rename RB040     HH_ID
rename RB030     PERS_ID

* check
tab1 YEAR COUNTRY
tabstat HH_ID, stats(min max n) by (COUNTRY) format(%10.0g)
tabstat PERS_ID, stats(min max n) by (COUNTRY) format(%12.0g)

* 3. sort by key variables
sort YEAR COUNTRY HH_ID PERS_ID

* 4.  save the file under a new name, change path to your own path 
save "pers_reg_l2011.dta", replace
**********************************************************************


**********************************************************************
* personal data
**********************************************************************
* 1. open the file
use  "udb_l11p_silc_course.dta", clear

* 2. rename the KEY VARIABLES
rename PB010     YEAR
rename PB020     COUNTRY
rename PX030     HH_ID
rename PB030     PERS_ID

* check
tab1 YEAR COUNTRY
tabstat HH_ID, stats(min max n) by (COUNTRY) format(%10.0g)
tabstat PERS_ID, stats(min max n) by (COUNTRY) format(%12.0g)

* 3. sort by KEY variables
sort YEAR COUNTRY HH_ID PERS_ID

* 4. save the file under a new name, change path to your own path 
save "pers_data_l2011.dta", replace
**********************************************************************
