**********************************************************************
* name of this file: 
* using_data_from_previous_years.do
*
* DwB Training Course on EU-SILC Longitudinal Data
* Paris, 19-21 February 2014
* Hands-on 
* Heike Wirth, GESIS
*
* see: Bruederl/Ludwig: Useful Stata Commands for
* Longitudinal Data Analysis
* University of Munich, May 2012
* http://www.ls3.soziologie.uni-muenchen.de/
* downloads/lehre/lehre_alt/statacommands.pdf
**********************************************************************

clear
capture log close
set more off

* change the path to where your original data is stored
cd "D:\Eigene Dateien\Dokumente\PARIS_2014\EXERCISE\DATA"

* choose name and directory for your loglog-file
log using "D:\Eigene Dateien\Dokumente\PARIS_2014\EXERCISE\hw_log", replace


**********************************************************************
*
* Using information from the year before
* X[1]    // X value of the first household/person year
* X[_N]   // X value of the last household/person year
* X[_n-1] // X value of the household/person year before
*  
**********************************************************************

use "hh_reg_data.dta", replace
sort COUNTRY HH_ID YEAR

* Example 1
* HS120 'Ability to make ends meet' first year/last year of interview

bysort HH_ID COUNTRY (YEAR) : gen FIRST_HS120=HS120[1]    //value of the first household year
bysort HH_ID COUNTRY (YEAR) : gen LAST_HS120 =HS120[_N]   //value of the last household year
bysort HH_ID COUNTRY (YEAR) : gen YB_HS120   =HS120[_n-1] //value of the household year before


********************************************************************************
* REMEMBER
*
*  _n in the example is used as a running counter within a by-group
*  _N in these examples is used for indexing the total number within each
*    by-group 
*
* what ist the difference between
* (a) bysort HH_ID COUNTRY YEAR    : gen FIRST_HS120=HS120[1]
* (b) bysort HH_ID COUNTRY (YEAR)  : gen FIRST_HS120=HS120[1]
*
* (a) data are sorted by HH_ID COUNTRY YEAR 
*     because there is only one record for the 'group' HH_ID COUNTRY YEAR
*     FIRST_HS120 will be identical to HS120 for this group 
*
* (b) data are sorted by YEAR within the 'group' HH_ID COUNTRY 
*     thus FIRST_HS120 will contain the category for the 1st year of the group
*
* 
* bysort HH_ID COUNTRY YEAR : gen F_HS120=HS120[1]
* list COUNTRY HH_ID YEAR HS120 FIRST_HS120 F_HS120 YB_HS120 in 1/10, clean nolab
*********************************************************************************
      
list COUNTRY HH_ID YEAR HS120 FIRST_HS120 LAST_HS120 YB_HS120 in 1/20, clean nolab

* "change" between first hhyear and last hhyear
*  main diagonal = 'stayers (no change between first & last hhyear)'

tab FIRST_HS120 LAST_HS120, row nofreq

* "change" between 'hhyear of interest' and previous hhyear

bysort YEAR: tab HS120 YB_HS120, row nofreq

* Example 2
* hhsize HX040
* "change" between first hhyear and last hhyear
*  main diagonal = 'stayers (no change between first & last hhyear)'


bysort HH_ID COUNTRY (YEAR) : gen FIRST_HX040=HX040[1]    //value of the first household year
bysort HH_ID COUNTRY (YEAR) : gen LAST_HX040 =HX040[_N]   //value of the last household year
bysort HH_ID COUNTRY (YEAR) : gen YB_HX040   =HX040[_n-1] //value of the household year before

tab FIRST_HX040 LAST_HX040, row nofreq
