**********************************************************************
* name of this file: 
* xtreg.do
*
* DwB Training Course on EU-SILC Longitudinal Data
* Paris, 19-21 February 2014
* Hands-on 
* Heike Wirth, GESIS
**********************************************************************

clear
capture log close
set more off

* change the path to where your original data is stored
cd "YOUR PATH"

* choose name and directory for your loglog-file
log using "YOUR LOG FILE", append


**********************************************************************
*
* We are interested in modeling how changes of the economic situation
* of the household affects the health of its members. As indicator
* for the economic situation we use HS120 "making ends meet".
*
* We have to merge this household level variable to the person data.
*
**********************************************************************

use "hh_reg_data.dta", clear

keep YEAR COUNTRY HH_ID HS120 HX090

merge 1:m YEAR COUNTRY HH_ID using person_reg_data.dta
tab _merge
keep if _merge==3
drop _merge

*********************************************************************
*
* Now we have to tell Stata data are from a panel: xtset
*
*********************************************************************

duplicates report PERS_ID YEAR
egen COUNTRY_NUM=group(COUNTRY)
gen double SPLIT_NR=mod(HH_ID,100) 
gen double IDENTIFIER  = (COUNTRY_NUM*1000000000000 + PERS_ID*100 + SPLIT_NR)
format IDENTIFIER %16.0g
tabstat IDENTIFIER, stats(min max count) format(%16.0g)
duplicates report IDENTIFIER YEAR
isid IDENTIFIER YEAR

xtset IDENTIFIER YEAR

* Now we can use all xt commands

* For our analysis we explore the data
tab1 PH010 HS120

* We recode health so that higher values reflect better health

gen HEALTH=-1*PH010+6
label define heal 1 "very bad" 2 "bad" 3 "fair" 4 "good" 5 "very good"
label value HEALTH heal
tab1 HEALTH

tab HEALTH HS120, m
tab HEALTH HS120, col

xtreg HEALTH HS120, fe

* We can also control for time-varying covariates, here age
xtreg HEALTH HS120 RX010, fe


* Now let us look at how income affects health

* We use equivalised income
sum HX090, de

* From cross-sectional results we would conclude that
* there is an effect

reg HEALTH HX090 RX010 if YEAR==2011

* But if we look at how changes in income affact changes in health
* we do not find any effect
xtreg HEALTH HX090 RX010, fe


*************************************************************************
*
* Fixed effects panel regression (also known as first difference regression)
* is identical to OLS regression when controlling for the nesting variable
* here person ID. 
* To show this we restrict the analysis to Austria, 
* we have to create a new ID variable with format "integer"
* and increase the size dor internal storage of data.
*
****************************************************************************

egen ID_NEW=group(IDENTIFIER)
set matsize 11000
reg HEALTH HS120 i.ID_NEW if COUNTRY=="AT"
xtreg HEALTH HS120 if COUNTRY=="AT", fe 
