**********************************************************************
* name of this file: 
* xtset.do
*
* DwB Training Course on EU-SILC Longitudinal Data
* Paris, 19-21 February 2014
* Hands-on 
* Heike Wirth, GESIS
**********************************************************************

clear
capture log close
set more off

* change the path to where your original data is stored
cd "YOUR PATH"

* choose name and directory for your loglog-file
log using "YOUR LOG FILE"

**********************************************************************
*
* Define data as panel data and use XT commands
*  
**********************************************************************

use "person_reg_data.dta", replace

* You can tell stata that data is from a panel using the xtset command
* For this you need unique identifiers for each person. Because PERS_ID 
* can be identical across countries we have to generate a unique identifer 
* by combining PERS_ID and COUNTRY
* ATTENTION: Because this is a large number you have to use data type "double"

* ATTENTION: This syntax works for data in the P file (person data)
*            It does not work in the R file!!!! (see solution below)


duplicates report COUNTRY PERS_ID YEAR
egen COUNTRY_NUM=group(COUNTRY)
gen double IDENTIFIER  = (COUNTRY_NUM*10000000000 + PERS_ID)
format IDENTIFIER %16.0g
tabstat IDENTIFIER, stats(min max count) format(%14.0g)
duplicates report IDENTIFIER YEAR
isid IDENTIFIER YEAR

* ATTENTION: This syntax works for the R file (person register)
*            You shouldn't use it in the P file if you are interested 
*            to follow persons even if they moved between households
*
* duplicates report COUNTRY PERS_ID YEAR
* egen COUNTRY_NUM=group(COUNTRY)
* gen double SPLIT_NR=mod(HH_ID,100) 
* gen double IDENTIFIER_R  = (COUNTRY_NUM*1000000000000 + PERS_ID*100 + SPLIT_NR)
* format IDENTIFIER_R %16.0g
* tabstat IDENTIFIER_R, stats(min max count) format(%16.0g)
* duplicates report IDENTIFIER_R YEAR
* isid IDENTIFIER_R YEAR

* With xtset you can now define the panel structure

xtset IDENTIFIER YEAR

* Now we can easily look at transitions

tab RB210
xttrans RB210, freq

* A powerful tool for panel analysis is the lag operator (L.);
* this operator allows you to use data from (the/a) previous record when 
* calculating a variable value for the current record.

* Let us assume you where interested in analysing the transition between 
* employment statuses. Then you have to know the current and previous 
* employment status. In a file that is sorted by persons and years this latter 
* information can be found on the record for the previous year.

* The correct use of the lag function assumes the data are sorted correctly;
* here by identifier and year

sort IDENTIFIER YEAR
gen RB210L=L.RB210
list COUNTRY YEAR HH_ID PERS_ID IDENTIFIER RB210 RB210L in 275/300, clean nolabel

tabulate RB210L RB210, row m
bysort YEAR: tabulate RB210L RB210, row
